<a id="types-aiobotocore-route53resolver"></a>

# types-aiobotocore-route53resolver

[![PyPI - types-aiobotocore-route53resolver](https://img.shields.io/pypi/v/types-aiobotocore-route53resolver.svg?color=blue)](https://pypi.org/project/types-aiobotocore-route53resolver)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-route53resolver.svg?color=blue)](https://pypi.org/project/types-aiobotocore-route53resolver)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-route53resolver?color=blue)](https://pypistats.org/packages/types-aiobotocore-route53resolver)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.Route53Resolver 2.1.1](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53resolver.html#Route53Resolver)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.1.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-route53resolver docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_route53resolver/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-route53resolver](#types-aiobotocore-route53resolver)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Route53Resolver`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Route53Resolver` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[route53resolver]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[route53resolver]'


# standalone installation
python -m pip install types-aiobotocore-route53resolver
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-route53resolver
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[route53resolver]` in your environment:

```bash
python -m pip install 'types-aiobotocore[route53resolver]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[route53resolver]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[route53resolver]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[route53resolver]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[route53resolver]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[route53resolver]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[route53resolver]` in your environment:

```bash
python -m pip install 'types-aiobotocore[route53resolver]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[route53resolver]` in your environment:

```bash
python -m pip install 'types-aiobotocore[route53resolver]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`Route53ResolverClient` provides annotations for
`session.create_client("route53resolver")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_route53resolver import Route53ResolverClient

session = get_session()
async with session.create_client("route53resolver") as client:
    client: Route53ResolverClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_route53resolver.paginator` module contains type annotations
for all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_route53resolver import Route53ResolverClient
from types_aiobotocore_route53resolver.paginator import (
    ListFirewallConfigsPaginator,
    ListFirewallDomainListsPaginator,
    ListFirewallDomainsPaginator,
    ListFirewallRuleGroupAssociationsPaginator,
    ListFirewallRuleGroupsPaginator,
    ListFirewallRulesPaginator,
    ListResolverConfigsPaginator,
    ListResolverDnssecConfigsPaginator,
    ListResolverEndpointIpAddressesPaginator,
    ListResolverEndpointsPaginator,
    ListResolverQueryLogConfigAssociationsPaginator,
    ListResolverQueryLogConfigsPaginator,
    ListResolverRuleAssociationsPaginator,
    ListResolverRulesPaginator,
    ListTagsForResourcePaginator,
)

session = get_session()
async with session.create_client("route53resolver") as client:
    client: Route53ResolverClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_firewall_configs_paginator: ListFirewallConfigsPaginator = client.get_paginator("list_firewall_configs")
        list_firewall_domain_lists_paginator: ListFirewallDomainListsPaginator = client.get_paginator("list_firewall_domain_lists")
        list_firewall_domains_paginator: ListFirewallDomainsPaginator = client.get_paginator("list_firewall_domains")
        list_firewall_rule_group_associations_paginator: ListFirewallRuleGroupAssociationsPaginator = client.get_paginator("list_firewall_rule_group_associations")
        list_firewall_rule_groups_paginator: ListFirewallRuleGroupsPaginator = client.get_paginator("list_firewall_rule_groups")
        list_firewall_rules_paginator: ListFirewallRulesPaginator = client.get_paginator("list_firewall_rules")
        list_resolver_configs_paginator: ListResolverConfigsPaginator = client.get_paginator("list_resolver_configs")
        list_resolver_dnssec_configs_paginator: ListResolverDnssecConfigsPaginator = client.get_paginator("list_resolver_dnssec_configs")
        list_resolver_endpoint_ip_addresses_paginator: ListResolverEndpointIpAddressesPaginator = client.get_paginator("list_resolver_endpoint_ip_addresses")
        list_resolver_endpoints_paginator: ListResolverEndpointsPaginator = client.get_paginator("list_resolver_endpoints")
        list_resolver_query_log_config_associations_paginator: ListResolverQueryLogConfigAssociationsPaginator = client.get_paginator("list_resolver_query_log_config_associations")
        list_resolver_query_log_configs_paginator: ListResolverQueryLogConfigsPaginator = client.get_paginator("list_resolver_query_log_configs")
        list_resolver_rule_associations_paginator: ListResolverRuleAssociationsPaginator = client.get_paginator("list_resolver_rule_associations")
        list_resolver_rules_paginator: ListResolverRulesPaginator = client.get_paginator("list_resolver_rules")
        list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    ```







### Literals

`types_aiobotocore_route53resolver.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_route53resolver.literals import (
    ActionType,
    AutodefinedReverseFlagType,
    BlockOverrideDnsTypeType,
    BlockResponseType,
    FirewallDomainImportOperationType,
    FirewallDomainListStatusType,
    FirewallDomainUpdateOperationType,
    FirewallFailOpenStatusType,
    FirewallRuleGroupAssociationStatusType,
    FirewallRuleGroupStatusType,
    IpAddressStatusType,
    ListFirewallConfigsPaginatorName,
    ListFirewallDomainListsPaginatorName,
    ListFirewallDomainsPaginatorName,
    ListFirewallRuleGroupAssociationsPaginatorName,
    ListFirewallRuleGroupsPaginatorName,
    ListFirewallRulesPaginatorName,
    ListResolverConfigsPaginatorName,
    ListResolverDnssecConfigsPaginatorName,
    ListResolverEndpointIpAddressesPaginatorName,
    ListResolverEndpointsPaginatorName,
    ListResolverQueryLogConfigAssociationsPaginatorName,
    ListResolverQueryLogConfigsPaginatorName,
    ListResolverRuleAssociationsPaginatorName,
    ListResolverRulesPaginatorName,
    ListTagsForResourcePaginatorName,
    MutationProtectionStatusType,
    ResolverAutodefinedReverseStatusType,
    ResolverDNSSECValidationStatusType,
    ResolverEndpointDirectionType,
    ResolverEndpointStatusType,
    ResolverQueryLogConfigAssociationErrorType,
    ResolverQueryLogConfigAssociationStatusType,
    ResolverQueryLogConfigStatusType,
    ResolverRuleAssociationStatusType,
    ResolverRuleStatusType,
    RuleTypeOptionType,
    ShareStatusType,
    SortOrderType,
    ValidationType,
    ServiceName,
    PaginatorName,
)

def check_value(value: ActionType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_route53resolver.type_defs` module contains structures and
shapes assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_route53resolver.type_defs import (
    AssociateFirewallRuleGroupRequestRequestTypeDef,
    AssociateFirewallRuleGroupResponseTypeDef,
    AssociateResolverEndpointIpAddressRequestRequestTypeDef,
    AssociateResolverEndpointIpAddressResponseTypeDef,
    AssociateResolverQueryLogConfigRequestRequestTypeDef,
    AssociateResolverQueryLogConfigResponseTypeDef,
    AssociateResolverRuleRequestRequestTypeDef,
    AssociateResolverRuleResponseTypeDef,
    CreateFirewallDomainListRequestRequestTypeDef,
    CreateFirewallDomainListResponseTypeDef,
    CreateFirewallRuleGroupRequestRequestTypeDef,
    CreateFirewallRuleGroupResponseTypeDef,
    CreateFirewallRuleRequestRequestTypeDef,
    CreateFirewallRuleResponseTypeDef,
    CreateResolverEndpointRequestRequestTypeDef,
    CreateResolverEndpointResponseTypeDef,
    CreateResolverQueryLogConfigRequestRequestTypeDef,
    CreateResolverQueryLogConfigResponseTypeDef,
    CreateResolverRuleRequestRequestTypeDef,
    CreateResolverRuleResponseTypeDef,
    DeleteFirewallDomainListRequestRequestTypeDef,
    DeleteFirewallDomainListResponseTypeDef,
    DeleteFirewallRuleGroupRequestRequestTypeDef,
    DeleteFirewallRuleGroupResponseTypeDef,
    DeleteFirewallRuleRequestRequestTypeDef,
    DeleteFirewallRuleResponseTypeDef,
    DeleteResolverEndpointRequestRequestTypeDef,
    DeleteResolverEndpointResponseTypeDef,
    DeleteResolverQueryLogConfigRequestRequestTypeDef,
    DeleteResolverQueryLogConfigResponseTypeDef,
    DeleteResolverRuleRequestRequestTypeDef,
    DeleteResolverRuleResponseTypeDef,
    DisassociateFirewallRuleGroupRequestRequestTypeDef,
    DisassociateFirewallRuleGroupResponseTypeDef,
    DisassociateResolverEndpointIpAddressRequestRequestTypeDef,
    DisassociateResolverEndpointIpAddressResponseTypeDef,
    DisassociateResolverQueryLogConfigRequestRequestTypeDef,
    DisassociateResolverQueryLogConfigResponseTypeDef,
    DisassociateResolverRuleRequestRequestTypeDef,
    DisassociateResolverRuleResponseTypeDef,
    FilterTypeDef,
    FirewallConfigTypeDef,
    FirewallDomainListMetadataTypeDef,
    FirewallDomainListTypeDef,
    FirewallRuleGroupAssociationTypeDef,
    FirewallRuleGroupMetadataTypeDef,
    FirewallRuleGroupTypeDef,
    FirewallRuleTypeDef,
    GetFirewallConfigRequestRequestTypeDef,
    GetFirewallConfigResponseTypeDef,
    GetFirewallDomainListRequestRequestTypeDef,
    GetFirewallDomainListResponseTypeDef,
    GetFirewallRuleGroupAssociationRequestRequestTypeDef,
    GetFirewallRuleGroupAssociationResponseTypeDef,
    GetFirewallRuleGroupPolicyRequestRequestTypeDef,
    GetFirewallRuleGroupPolicyResponseTypeDef,
    GetFirewallRuleGroupRequestRequestTypeDef,
    GetFirewallRuleGroupResponseTypeDef,
    GetResolverConfigRequestRequestTypeDef,
    GetResolverConfigResponseTypeDef,
    GetResolverDnssecConfigRequestRequestTypeDef,
    GetResolverDnssecConfigResponseTypeDef,
    GetResolverEndpointRequestRequestTypeDef,
    GetResolverEndpointResponseTypeDef,
    GetResolverQueryLogConfigAssociationRequestRequestTypeDef,
    GetResolverQueryLogConfigAssociationResponseTypeDef,
    GetResolverQueryLogConfigPolicyRequestRequestTypeDef,
    GetResolverQueryLogConfigPolicyResponseTypeDef,
    GetResolverQueryLogConfigRequestRequestTypeDef,
    GetResolverQueryLogConfigResponseTypeDef,
    GetResolverRuleAssociationRequestRequestTypeDef,
    GetResolverRuleAssociationResponseTypeDef,
    GetResolverRulePolicyRequestRequestTypeDef,
    GetResolverRulePolicyResponseTypeDef,
    GetResolverRuleRequestRequestTypeDef,
    GetResolverRuleResponseTypeDef,
    ImportFirewallDomainsRequestRequestTypeDef,
    ImportFirewallDomainsResponseTypeDef,
    IpAddressRequestTypeDef,
    IpAddressResponseTypeDef,
    IpAddressUpdateTypeDef,
    ListFirewallConfigsRequestRequestTypeDef,
    ListFirewallConfigsResponseTypeDef,
    ListFirewallDomainListsRequestRequestTypeDef,
    ListFirewallDomainListsResponseTypeDef,
    ListFirewallDomainsRequestRequestTypeDef,
    ListFirewallDomainsResponseTypeDef,
    ListFirewallRuleGroupAssociationsRequestRequestTypeDef,
    ListFirewallRuleGroupAssociationsResponseTypeDef,
    ListFirewallRuleGroupsRequestRequestTypeDef,
    ListFirewallRuleGroupsResponseTypeDef,
    ListFirewallRulesRequestRequestTypeDef,
    ListFirewallRulesResponseTypeDef,
    ListResolverConfigsRequestRequestTypeDef,
    ListResolverConfigsResponseTypeDef,
    ListResolverDnssecConfigsRequestRequestTypeDef,
    ListResolverDnssecConfigsResponseTypeDef,
    ListResolverEndpointIpAddressesRequestRequestTypeDef,
    ListResolverEndpointIpAddressesResponseTypeDef,
    ListResolverEndpointsRequestRequestTypeDef,
    ListResolverEndpointsResponseTypeDef,
    ListResolverQueryLogConfigAssociationsRequestRequestTypeDef,
    ListResolverQueryLogConfigAssociationsResponseTypeDef,
    ListResolverQueryLogConfigsRequestRequestTypeDef,
    ListResolverQueryLogConfigsResponseTypeDef,
    ListResolverRuleAssociationsRequestRequestTypeDef,
    ListResolverRuleAssociationsResponseTypeDef,
    ListResolverRulesRequestRequestTypeDef,
    ListResolverRulesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PutFirewallRuleGroupPolicyRequestRequestTypeDef,
    PutFirewallRuleGroupPolicyResponseTypeDef,
    PutResolverQueryLogConfigPolicyRequestRequestTypeDef,
    PutResolverQueryLogConfigPolicyResponseTypeDef,
    PutResolverRulePolicyRequestRequestTypeDef,
    PutResolverRulePolicyResponseTypeDef,
    ResolverConfigTypeDef,
    ResolverDnssecConfigTypeDef,
    ResolverEndpointTypeDef,
    ResolverQueryLogConfigAssociationTypeDef,
    ResolverQueryLogConfigTypeDef,
    ResolverRuleAssociationTypeDef,
    ResolverRuleConfigTypeDef,
    ResolverRuleTypeDef,
    ResponseMetadataTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TargetAddressTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateFirewallConfigRequestRequestTypeDef,
    UpdateFirewallConfigResponseTypeDef,
    UpdateFirewallDomainsRequestRequestTypeDef,
    UpdateFirewallDomainsResponseTypeDef,
    UpdateFirewallRuleGroupAssociationRequestRequestTypeDef,
    UpdateFirewallRuleGroupAssociationResponseTypeDef,
    UpdateFirewallRuleRequestRequestTypeDef,
    UpdateFirewallRuleResponseTypeDef,
    UpdateResolverConfigRequestRequestTypeDef,
    UpdateResolverConfigResponseTypeDef,
    UpdateResolverDnssecConfigRequestRequestTypeDef,
    UpdateResolverDnssecConfigResponseTypeDef,
    UpdateResolverEndpointRequestRequestTypeDef,
    UpdateResolverEndpointResponseTypeDef,
    UpdateResolverRuleRequestRequestTypeDef,
    UpdateResolverRuleResponseTypeDef,
)

def get_structure() -> AssociateFirewallRuleGroupRequestRequestTypeDef:
    return {
      ...
    }
```

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

## What's new

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/vemel/mypy_boto3_builder/releases).

## Versioning

`types-aiobotocore-route53resolver` version is the same as related
`aiobotocore` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_route53resolver/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
